<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'Salva come una bozza',
	'bouton_envoyer_message' => 'Messaggio completato: invio',
	'bouton_envoyer_message_maintenant' => 'Invia adesso',

	// C
	'cal_jour_entier' => 'Giorno',
	'cal_par_jour' => 'giorno',
	'cal_par_mois' => 'mese',
	'cal_par_semaine' => 'settimana',

	// E
	'erreur_date' => 'La data è sbagliata',
	'erreur_date_avant_apres' => 'Per favore inserite una data di fine successiva alla data d’inizio.',
	'erreur_date_corrigee' => 'La data è stata corretta',
	'erreur_destinataire_invalide' => 'Il destinartario @dest@ non è valido',
	'erreur_heure' => 'L’ora è sbagliata',
	'erreur_heure_corrigee' => 'L’ora è stata corretta',

	// I
	'icone_ecrire_nouveau_message' => 'Invia un nuovo messaggio',
	'icone_ecrire_nouveau_pensebete' => 'Scrivi un nuovo promemoria',
	'icone_ecrire_nouvelle_annonce' => 'Invia un nuovo annuncio',
	'icone_effacer_message' => 'Cancella questo messaggio',
	'icone_modifier_annonce' => 'Modifica questo annuncio',
	'icone_modifier_message' => 'Modificare questo messaggio',
	'icone_modifier_pensebete' => 'Modifica questo promemoria',
	'icone_supprimer_message' => 'Cancella questo messaggio',
	'info_1_message_envoye' => '1 messaggio inviato',
	'info_1_message_nonlu' => '1 nuovo messaggio',
	'info_agenda_interne' => 'Agenda interna',
	'info_message_a' => 'A',
	'info_message_date' => 'Data',
	'info_message_date_debut' => 'Data iniziale',
	'info_message_date_fin' => 'Data finale',
	'info_message_de' => 'Da',
	'info_message_non_lu' => 'Nuovo messaggio',
	'info_message_objet' => 'Oggetto',
	'info_nb_messages_envoyes' => '@nb@ messaggi inviati',
	'info_nb_messages_nonlus' => '@nb@ nuovi messaggi',
	'info_selection_annonces' => 'Annunci',
	'info_selection_messages' => 'Messaggi',
	'info_selection_pensebetes' => 'Promemoria',
	'info_type_message_affich' => 'Annuncio',
	'info_type_message_normal' => 'Messaggio',
	'info_type_message_pb' => 'Promemoria',
	'info_type_message_rv' => 'Appuntamento',

	// L
	'label_destinataires' => 'A',
	'label_texte' => 'Testo:',
	'label_titre' => 'Titolo',
	'loading' => 'Caricamento...',

	// M
	'message' => 'Inserisci la tua email, prima del contenuto del sito',
	'messages' => 'Messaggi',

	// N
	'notification_annonce_lire_a_ladresse' => 'Puoi leggerla al seguente url @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] Annuncio globale',
	'notification_message_lire_a_ladresse' => 'Puoi leggerlo e replicare all’indirizzo @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] Nuovo messaggio',
	'notification_message_recu_de' => 'Hai ricevuto un nuovo messa da @nom@.',

	// T
	'texte_message_brouillon' => 'Questo messaggio è salvato come bozza',
	'titre_agenda_rv' => 'Appuntamento',
	'titre_boite_envoi' => 'Posta in uscita',
	'titre_boite_reception' => 'Posta in entrata'
);

?>
